==> apache-rat-0.16-src.zip: apache-rat-0.16/apache-rat-core/src/test/java/org/apache/rat/analysis/matchers/NotMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */
package org.apache.rat.analysis.matchers;

import static org.junit.Assert.assertEquals;

import org.apache.rat.analysis.IHeaderMatcher;
import org.apache.rat.analysis.IHeaderMatcher.State;
import org.apache.rat.testhelpers.TestingMatcher;
import org.junit.Test;

public class NotMatcherTest {

    private void assertValues(IHeaderMatcher target, State hello, State world, State finalize) {
        assertEquals(State.i, target.currentState());
        assertEquals("hello match", hello, target.matches("hello"));
        assertEquals("hello current", hello, target.currentState());
        assertEquals("world match", world, target.matches("world"));
        assertEquals("world current", world, target.currentState());
        assertEquals("finalize", finalize, target.finalizeState());
        assertEquals("finalize current", finalize, target.currentState());
    }

    @Test
    public void testTrue() {
        IHeaderMatcher one = new TestingMatcher("one", true);
        NotMatcher target = new NotMatcher("Testing", one);
        assertValues(target, State.f, State.f, State.f);

        one = new TestingMatcher("one", false, true);
        target = new NotMatcher("Testing", one);
        assertValues(target, State.i, State.f, State.f);
        target.reset();
        assertEquals(State.i, target.currentState());
    }

    @Test
    public void testFalse() {
        TestingMatcher one = new TestingMatcher("one", false, false);
        one.finalState = State.t;
        NotMatcher target = new NotMatcher("Testing", one);
        assertValues(target, State.i, State.i, State.f);
        target.reset();
        assertEquals(State.i, target.currentState());

    }
}

==> apache-rat-0.17-src.zip: apache-rat-0.17/apache-rat-core/src/test/java/org/apache/rat/analysis/matchers/NotMatcherTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */
package org.apache.rat.analysis.matchers;

import org.apache.rat.analysis.IHeaderMatcher;
import org.apache.rat.testhelpers.TestingMatcher;
import org.junit.jupiter.api.Test;

public class NotMatcherTest extends AbstractMatcherTest {

    @Test
    public void test() {
        IHeaderMatcher one = new TestingMatcher("one", true, false);
        NotMatcher target = new NotMatcher("Testing", one);
        assertValues(target, false, true);
    }

}
